# Upstream does not maintain a soversion so we define one here.
# abi-compliance-checker will be used to determine if an abi breakage occurs
# and the soversion will be incremented.
%global sover                            1.6

%define libbuffer                        %mklibname buffer %{sover}
%define libftoa                          %mklibname ftoa %{sover}
%define libgeneratedsaxparser            %mklibname generatedsaxparser %{sover}
%define libmathmlsolver                  %mklibname mathmlsolver %{sover}
%define libopencolladabaseutils          %mklibname opencolladabaseutils %{sover}
%define libopencolladaframework          %mklibname opencolladaframework %{sover}
%define libopencolladasaxframeworkloader %mklibname opencolladasaxframeworkloader %{sover}
%define libopencolladastreamwriter       %mklibname opencolladastreamwriter %{sover}
%define libutf                           %mklibname utf %{sover}
%define devname                          %mklibname %{name} -d

%global upname  OpenCOLLADA

%global uname   openCOLLADA

%define rel	4

Name:           opencollada
Version:        1.6.68
Release:        %mkrel %{rel}
License:        MIT
Summary:        Collada 3D import and export libraries
Group:          System/Libraries
Url:            https://collada.org/mediawiki/index.php/OpenCOLLADA

Source0:        https://github.com/KhronosGroup/OpenCOLLADA/archive/v%{version}/%{upname}-%{version}.tar.gz
# based from Gentoo: https://github.com/KhronosGroup/OpenCOLLADA/pull/561
Patch0:         opencollada-1.6.62-cmake-fixes.patch
# don't build DAEvalidator app
Patch1:         opencollada-1.6.62-no-daevalidator.patch
# fix build against pcre 8.42
Patch2:         opencollada-1.6.62-pcre-8.42.patch

BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(lib3ds)
BuildRequires:  pkgconfig(libpcreposix)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(zziplib)

%description
COLLADA is a royalty-free XML schema that enables digital asset
exchange within the interactive 3D industry.
OpenCOLLADA is a Google Summer of Code Open Source project providing
libraries for 3D file interchange between applications like blender.
COLLADABaseUtils          Utils used by many of the other projects
COLLADAFramework          Datamodel used to load COLLADA files
COLLADAStreamWriter       Sources (Library to write COLLADA files)
COLLADASaxFrameworkLoader Library that loads COLLADA files in a sax
                          like manner into the framework data model
COLLADAValidator          XML validator for COLLADA files, based on
                          the COLLADASaxFrameworkLoader
GeneratedSaxParser        Library used to load xml files in the way
                          used by COLLADASaxFrameworkLoader

%package        doc
Summary:        Developer documentation for %{uname}
Group:          Documentation
BuildArch:      noarch

%description    doc
This package provides documentation for %{name}.

%package -n     %{libbuffer}
Summary:        Collada 3D import and export libraries
Group:          System/Libraries
# ease upgrade mga7
Conflicts:      %{_lib}opencollada0.3 < 0-6

%description -n %{libbuffer}
COLLADA is a XML schema that enables digital asset exchange within
the interactive 3D industry. OpenCOLLADA is a project providing
libraries for 3D file interchange between applications like Blender.

%package -n     %{libftoa}
Summary:        Collada 3D import and export libraries
Group:          System/Libraries
# ease upgrade mga7
Conflicts:      %{_lib}opencollada0.3 < 0-6

%description -n %{libftoa}
COLLADA is a XML schema that enables digital asset exchange within
the interactive 3D industry. OpenCOLLADA is a project providing
libraries for 3D file interchange between applications like Blender.

%package -n     %{libgeneratedsaxparser}
Summary:        Collada 3D import and export libraries
Group:          System/Libraries
# ease upgrade mga7
Conflicts:      %{_lib}opencollada0.3 < 0-6

%description -n %{libgeneratedsaxparser}
COLLADA is a XML schema that enables digital asset exchange within
the interactive 3D industry. OpenCOLLADA is a project providing
libraries for 3D file interchange between applications like Blender.

GeneratedSaxParser is the library used to load xml files in the way
used by COLLADASaxFrameworkLoader.

%package -n     %{libmathmlsolver}
Summary:        Collada 3D import and export libraries
Group:          System/Libraries
# ease upgrade mga7
Conflicts:      %{_lib}opencollada0.3 < 0-6

%description -n %{libmathmlsolver}
COLLADA is a XML schema that enables digital asset exchange within
the interactive 3D industry. OpenCOLLADA is a project providing
libraries for 3D file interchange between applications like Blender.

%package -n     %{libopencolladabaseutils}
Summary:        Collada 3D import and export libraries
Group:          System/Libraries
# ease upgrade mga7
Conflicts:      %{_lib}opencollada0.3 < 0-6

%description -n %{libopencolladabaseutils}
COLLADA is a XML schema that enables digital asset exchange within
the interactive 3D industry. OpenCOLLADA is a project providing
libraries for 3D file interchange between applications like Blender.

COLLADABaseUtils is the package of utilities used by many of the other
projects.

%package -n     %{libopencolladaframework}
Summary:        Collada 3D import and export libraries
Group:          System/Libraries
# ease upgrade mga7
Conflicts:      %{_lib}opencollada0.3 < 0-6

%description -n %{libopencolladaframework}
COLLADA is a XML schema that enables digital asset exchange within
the interactive 3D industry. OpenCOLLADA is a project providing
libraries for 3D file interchange between applications like Blender.

COLLADAFramework is the datamodel used to load COLLADA files.

%package -n     %{libopencolladasaxframeworkloader}
Summary:        Collada 3D import and export libraries
Group:          System/Libraries
# ease upgrade mga7
Conflicts:      %{_lib}opencollada0.3 < 0-6

%description -n %{libopencolladasaxframeworkloader}
COLLADA is a XML schema that enables digital asset exchange within
the interactive 3D industry. OpenCOLLADA is a project providing
libraries for 3D file interchange between applications like Blender.

COLLADASaxFrameworkLoader is a library that loads COLLADA files in a
SAX-like manner into the data framework model and is used by
COLLADASaxFrameworkLoader.

%package -n     %{libopencolladastreamwriter}
Summary:        Collada 3D import and export libraries
Group:          System/Libraries
# ease upgrade mga7
Conflicts:      %{_lib}opencollada0.3 < 0-6

%description -n %{libopencolladastreamwriter}
COLLADA is a XML schema that enables digital asset exchange within
the interactive 3D industry. OpenCOLLADA is a project providing
libraries for 3D file interchange between applications like Blender.

COLLADAStreamWriter contains the library to write COLLADA files.

%package -n     %{libutf}
Summary:        Collada 3D import and export libraries
Group:          System/Libraries
# ease upgrade mga7
Conflicts:      %{_lib}opencollada0.3 < 0-6

%description -n %{libutf}
COLLADA is a XML schema that enables digital asset exchange within
the interactive 3D industry. OpenCOLLADA is a project providing
libraries for 3D file interchange between applications like Blender.

%package -n     %{devname}
Summary:        Include files for openCOLLADA development
Group:          Development/C
Requires:       %{libbuffer} = %{version}-%{release}
Requires:       %{libftoa} = %{version}-%{release}
Requires:       %{libgeneratedsaxparser} = %{version}-%{release}
Requires:       %{libmathmlsolver} = %{version}-%{release}
Requires:       %{libopencolladabaseutils} = %{version}-%{release}
Requires:       %{libopencolladaframework} = %{version}-%{release}
Requires:       %{libopencolladasaxframeworkloader} = %{version}-%{release}
Requires:       %{libopencolladastreamwriter} = %{version}-%{release}
Requires:       %{libutf} = %{version}-%{release}
Provides:       %{uname}-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
This package provides the include files necessary to build and
develop with the %{uname} export and import libraries.

%package        utils
Summary:        XML validator for COLLADA files
Group:          Development/Tools

%description    utils
XML validator for COLLADA files, based on the COLLADASaxFrameworkLoader.


%prep
%setup -q -n %{upname}-%{version}
%autopatch -p1

# Remove unused bundled libraries
rm -rf Externals/{Cg,expat,lib3ds,LibXML,MayaDataModel,pcre,zlib,zziplib}

# Add some docs, need to fix eol encoding with dos2unix in some files.
find ./ -name .project -delete
cp -pf COLLADAStreamWriter/README README.COLLADAStreamWriter
cp -pf COLLADAStreamWriter/LICENSE ./

iconv -f ISO_8859-1 -t utf-8 COLLADAStreamWriter/AUTHORS > \
  COLLADAStreamWriter/AUTHORS.tmp
touch -r COLLADAStreamWriter/AUTHORS COLLADAStreamWriter/AUTHORS.tmp
mv COLLADAStreamWriter/AUTHORS.tmp COLLADAStreamWriter/AUTHORS

dos2unix -f -k README.COLLADAStreamWriter
dos2unix -f -k LICENSE
dos2unix -f -k README
find htdocs/ -name *.php -exec dos2unix -f {} \;
find htdocs/ -name *.css -exec dos2unix -f {} \;


%build
%cmake -DUSE_STATIC=OFF \
       -DUSE_SHARED=ON \
       -DCMAKE_SKIP_RPATH=ON

%cmake_build


%install
%cmake_install

# Manually install binary
mkdir -p %{buildroot}%{_bindir}/
install -p -m 0755 build/bin/* %{buildroot}%{_bindir}/

# Install MathMLSolver headers
mkdir -p %{buildroot}%{_includedir}/MathMLSolver
cp -a Externals/MathMLSolver/include/* %{buildroot}%{_includedir}/MathMLSolver/

%files doc
%doc htdocs/

%files -n %{libbuffer}
%{_libdir}/libbuffer.so.%{sover}

%files -n %{libftoa}
%{_libdir}/libftoa.so.%{sover}

%files -n %{libgeneratedsaxparser}
%{_libdir}/libGeneratedSaxParser.so.%{sover}

%files -n %{libmathmlsolver}
%{_libdir}/libMathMLSolver.so.%{sover}

%files -n %{libopencolladabaseutils}
%{_libdir}/libOpenCOLLADABaseUtils.so.%{sover}

%files -n %{libopencolladaframework}
%{_libdir}/libOpenCOLLADAFramework.so.%{sover}

%files -n %{libopencolladasaxframeworkloader}
%{_libdir}/libOpenCOLLADASaxFrameworkLoader.so.%{sover}

%files -n %{libopencolladastreamwriter}
%doc README README.COLLADAStreamWriter COLLADAStreamWriter/AUTHORS
%license LICENSE
%{_libdir}/libOpenCOLLADAStreamWriter.so.%{sover}

%files -n %{libutf}
%{_libdir}/libUTF.so.%{sover}

%files -n %{devname}
%{_libdir}/*.so
%{_libdir}/cmake/%{upname}/
%{_includedir}/*

%files utils
%doc README README.COLLADAStreamWriter COLLADAStreamWriter/AUTHORS
%license LICENSE
%{_bindir}/*


%changelog
* Sun Mar 16 2025 wally <wally> 1.6.68-4.mga10
+ Revision: 2164973
- rebuild for libxml2 2.13.6

* Fri Apr 01 2022 umeabot <umeabot> 1.6.68-3.mga9
+ Revision: 1839408
- Mageia 9 Mass Rebuild

* Fri Feb 14 2020 umeabot <umeabot> 1.6.68-2.mga8
+ Revision: 1522021
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Mon Jan 14 2019 luigiwalser <luigiwalser> 1.6.68-1.mga7
+ Revision: 1356234
- 1.6.68

* Sun Sep 23 2018 umeabot <umeabot> 1.6.63-2.mga7
+ Revision: 1299985
- Mageia 7 Mass Rebuild

* Sun Jul 22 2018 daviddavid <daviddavid> 1.6.63-1.mga7
+ Revision: 1244942
- new version: 1.6.63

* Sat May 12 2018 daviddavid <daviddavid> 1.6.62-1.mga7
+ Revision: 1228527
- new version: 1.6.62
- now soversion is 1.6
- split out all opencollada libraries
- add patch to fix build with pcre 8.42
- do not build daevalidator for now (broken)

* Tue Sep 20 2016 wally <wally> 0-5.gitcaad49c.1.mga6
+ Revision: 1054677
- fix obsoletes

* Tue Sep 20 2016 wally <wally> 0-5.gitcaad49c.mga6
+ Revision: 1054669
- fix libification

* Mon Sep 19 2016 tv <tv> 0-4.gitcaad49c.mga6
+ Revision: 1054205
- new git snapshot

* Fri Feb 12 2016 umeabot <umeabot> 0-4.git3335ac1.3.mga6
+ Revision: 956519
- Mageia 6 Mass Rebuild

* Wed Aug 26 2015 tv <tv> 0-4.git3335ac1.2.mga6
+ Revision: 869865
- rebuild with gcc5

* Wed Aug 26 2015 fwang <fwang> 0-3.git3335ac1.2.mga6
+ Revision: 869507
- rebuild for gcc5

* Tue Jul 28 2015 daviddavid <daviddavid> 0-3.git3335ac1.1.mga6
+ Revision: 858356
- update to git checkout which works with blender 2.75
- provides opencollada-devel

* Fri Nov 14 2014 tv <tv> 0-2.mga5
+ Revision: 797064
- provides openCOLLADA-devel

* Fri Nov 14 2014 tv <tv> 0-1.mga5
+ Revision: 797046
- imported package opencollada


* Fri Nov 14 2014 Thierry Vignaud <tv@mageia.org> 0-1.mga5
- import from FC 
- BR pcreposix
- use pkgconfig() style BR
- patch 2: fix build

* Thu Oct 09 2014 Sandro Mani <manisandro@gmail.com> - 0-20.git69b844d
- Add patch for missing includes which causes blender FTBFS

* Fri Sep  5 2014 Richard Shaw <hobbes1069@gmail.com> - 0-19.git69b844d
- Update to lastest git checkout.

* Thu May 09 2013 Richard Shaw <hobbes1069@gmail.com> - 0-15
- Update to latest upstream checkout. Required for blender 2.67.
- Add support for EPEL 6 build.

* Mon Jun 18 2012 Richard Shaw <hobbes1069@gmail.com> - 0-12.svn871
- Update to latest svn.
- Add MathMLSolver includes.

* Fri Feb 10 2012 Petr Pisar <ppisar@redhat.com> - 0-11.svn864
- Rebuild against PCRE 8.30

* Thu Jan 05 2012 Richard Shaw <hobbes1069@gmail.com> - 0-10
- Rebuild for GCC 4.7.0.
- Change how library soversion is set and test for abi breakages.
- Fix overriding of required build flags.

* Wed Oct 26 2011 Richard Shaw <hobbes1069@gmail.com> - 0-9
- Update to svn revision 864.

* Wed Oct 26 2011 Richard Shaw <hobbes1069@gmail.com> - 0-8
- Update to svn revision 863.
- Fix typo in spec file.

* Thu Oct 06 2011 Richard Shaw <hobbes1069@gmail.com> - 0-6
- Update to svn revision 847.

* Wed Apr 27 2011 Richard Shaw <hobbes1069@gmail.com> - 0-5
- Created -utils and -doc sub-packages.
- Corrected installation location of -devel header files.

* Wed Apr 27 2011 Richard Shaw <hobbes1069@gmail.com> - 0-4
- Move from scons to cmake for building.
- Various other fixes.

* Thu Apr 21 2011 Richard Shaw <hobbes1069@gmail.com> - 0-3
- Switched from expat to libxml2 for xml support.
- Updated to svn838

* Fri Apr 15 2011 Richard Shaw <hobbes1069@gmail.com> - 0-2
- Updated spec file for better packaging compliance
- Fixed some rpmlint warnings

* Tue Apr 12 2011 Richard Shaw <hobbes1069@gmail.com> - 0-1
- Updated spec file for Fedora packaging compliance

* Thu Mar 31 2011 davejplater@gmail.com
- Update to svn836
- Upstream changes :
  * fix validation preprocessor flag
  * inti member variables
  * fix uri copy ctor, add missing includes
  * replace asserts
  * fix import
  * fix crash in utf conversion with recent gcc
  * replace asserts by custom assert

* Fri Feb 11 2011 davejplater@gmail.com
- Update to svn827
- Upstream changes:
  * fix Issue 125: cgfx shader source file is not honoring the
  search path on export.
  * fix Issue 89: CONTINUITY semantic is not defined. Define all
  semantics in COLLADASWInputList.h
  * partially fix Issue 71: wrong opacity for effects without set
  transparency
  * fix Issue 65: COLLADASaxFWL::Loader::loadDocument() don't check
  if the file correctly loads
  * fix Issue 62: build fixes for linux (gcc 4.4.3)
  * ignore bin and lib folder in pcre
  * Issue 35: IWriter start, cancel, and finish methods not called
  * remove precompiled pcre pattern from source
  * fix Issue 122: Root::loadDocument("../a/b/c.dae") attempts to
  open "../a/a/b/c.dae"
  * Issue 145: std::terminate() while loading lightwave dae through
  OpenCOLLADAValidator
  * fix Issue 146: OpenCOLLADAValidator crash
  COLLADASaxFWL::LibraryEffectsLoader::handleTexture
  * fix Issue 151: CMakeLists.txt overwrites custom CMAKE_CXX_FLAGS
  * Issue 153: crash in <articulated_system> improvements in
  kinematics loader related to mathml

* Fri Jan  7 2011 davejplater@gmail.com
- Spec file change to fix SLE_11_SP1 build made by repabuild.

* Mon Dec 27 2010 davejplater@gmail.com
- Update to svn788
- Upstream changes
  * fix Issue 148: Glitch in ftoa and dtoa (rename variables)

* Mon Nov 22 2010 davejplater@gmail.com
- Update to svn785
- Prevent build of dae2ogre with openCOLLADA-nodae2ogre.patch
- Upstream changes :
  * apply path from Issue 4: CMake or Scons
  * fix performance issue with many materials
  * fix: do not write empty <extra> element in <profile_COMMON>
  * apply patch (only first change) provided in Issue 136: Fix for
  color sets not exporting in colladaMaya
  * fix Issue 137: SetParam does not properly export float<n> with
  0's in it

* Sat Nov  6 2010 davejplater@gmail.com
- Update to svn 779 Removed openCOLLADA-assign_value.patch which is
  already incorporated in this revision.
- Upstream changes :
  * fix Issue 126: cgfx shader source file is not honoring the search
  path on export.
  * apply patch provided in Issue 4: CMake or Scons (add cmake files)
  * fix Issue 132: Small fix from compiling blender - collada with
  - Wall -Werror
  * fix Issue 131: Gcc will be initialized after warning fixes

* Tue Oct 26 2010 pth@suse.de
- Actually assign the passed value in setter function.
- Manually strip libraries

* Sun Oct 24 2010 davejplater@gmail.com
- Added patch COLLADA-linuxbuild.patch to fix shared lib build includes.
- Added patch openCOLLADA-buildflags.patch for optflags.
- Added patch openCOLLADA-soname.patch to add sonames to libs.

* Mon Oct 18 2010 davejplater@gmail.com
- Created new package openCOLLADA needed by blender-2.5x
- OpenCOLLADA is a stream based reader and writer library for
  COLLADA files. support@opencollada.org
